# Generated by Django 4.2.14 on 2025-02-03 13:51
import django.db.models.deletion
from django.db import migrations, models


def move_data(apps, schema_editor):
    Account = apps.get_model("activate_account", "Account")
    AccountIdentifier = apps.get_model("activate_account", "AccountIdentifier")
    for account in Account.objects.filter(deleted_at__isnull=True):
        AccountIdentifier.objects.create(
            account_id=account,
            last_name=account.last_name,
            date_of_birth=account.date_of_birth,
            code=account.code,
        )


def reverse_move_data(apps, schema_editor):
    AccountIdentifier = apps.get_model("activate_account", "AccountIdentifier")
    identifier = AccountIdentifier.objects.select_related("account_id").first()
    if identifier:
        account = identifier.account_id
        account.last_name = identifier.last_name
        account.date_of_birth = identifier.date_of_birth
        account.code = identifier.code
        account.valid_at = identifier.date_of_birth
        account.save()


class Migration(migrations.Migration):
    dependencies = [
        ("activate_account", "0005_remove_account_unique_account_account_created_at_and_more"),
    ]

    operations = [
        migrations.CreateModel(
            name="AccountIdentifier",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                    ),
                ),
                ("last_name", models.CharField(db_collation="case_insensitive", max_length=100)),
                ("date_of_birth", models.DateField()),
                ("code", models.CharField(max_length=100)),
            ],
        ),
        migrations.AddField(
            model_name="accountidentifier",
            name="account_id",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                related_name="account_identifier",
                to="activate_account.account",
            ),
        ),
        migrations.RemoveConstraint(
            model_name="account",
            name="unique_account",
        ),
        migrations.RemoveConstraint(
            model_name="account",
            name="fields_not_nullable_if_deleted_at_is_not_null",
        ),
        migrations.RunPython(move_data, reverse_code=reverse_move_data),
        migrations.RemoveField(
            model_name="account",
            name="code",
        ),
        migrations.RemoveField(
            model_name="account",
            name="date_of_birth",
        ),
        migrations.RemoveField(
            model_name="account",
            name="last_name",
        ),
        migrations.AddConstraint(
            model_name="accountidentifier",
            constraint=models.UniqueConstraint(
                models.F("last_name"),
                models.F("date_of_birth"),
                models.F("code"),
                name="unique_account_identifier",
            ),
        ),
    ]
